@@ -43,6 +43,7 @@ class PartMan : public QObject
     enum TwitFlag {
         OldLayout,
         VirtualDevices,
+        VirtualBD,
         AutoCrypto,
         CryptoV
     };
@@ -64,7 +65,7 @@ class PartMan : public QObject
     static QString translateUse(const QString &alias);
     static QString describeUse(const QString &use);
     void clearPartitionTables(const QString &dev);
-    bool formatLinuxPartition(const QString &dev, const QString &type, bool chkBadBlocks, const QString &label);
+    bool formatLinuxPartition(const QString &dev, const QString &format, bool chkBadBlocks, const QString &label);
     void setEncryptChecks(const QString &use,
         enum Qt::CheckState state, QTreeWidgetItem *exclude);
     bool calculatePartBD();
@@ -73,18 +74,16 @@ class PartMan : public QObject
     inline bool twitFlag(const QTreeWidgetItem *twit, const TwitFlag flag) const;
     inline void twitSetFlag(QTreeWidgetItem *twit, const TwitFlag flag, const bool value);
     inline bool twitCanUse(QTreeWidgetItem *twit);
-    inline bool twitIsOldLayout(const QTreeWidgetItem *twit, const bool chkUp=true) const;
     inline long long twitSize(QTreeWidgetItem *twit, const bool bytes=false);
     inline bool twitWillFormat(QTreeWidgetItem *twit);
     inline QString twitUseFor(QTreeWidgetItem *twit);
-    inline bool twitIsMapped(const QTreeWidgetItem *twit) const;
     inline bool twitWillMap(const QTreeWidgetItem *twit) const;
     inline QString twitMappedDevice(const QTreeWidgetItem *twit, const bool full=false) const;
     inline QComboBox *twitComboBox(QTreeWidgetItem  *twit, int column);
     inline QLineEdit *twitLineEdit(QTreeWidgetItem  *twit, int column);
     void spinSizeValueChange(int i);
     void comboUseTextChange(const QString &text);
-    void comboTypeTextChange(const QString &);
+    void comboFormatTextChange(const QString &);
     void treeItemChange(QTreeWidgetItem *item, int column);
     void treeSelChange();
     void treeMenu(const QPoint &);
